@@ -738,14 +738,14 @@ def symbols_list(apikey: str) -> typing.List[typing.Dict]:
 
 def stock_screener(
     apikey: str,
-    market_cap_more_than: int = None,
-    market_cap_lower_than: int = None,
-    beta_more_than: int = None,
-    beta_lower_than: int = None,
-    volume_more_than: int = None,
-    volume_lower_than: int = None,
-    dividend_more_than: int = None,
-    dividend_lower_than: int = None,
+    market_cap_more_than: typing.Union[float, int] = None,
+    market_cap_lower_than: typing.Union[float, int] = None,
+    beta_more_than: typing.Union[float, int] = None,
+    beta_lower_than: typing.Union[float, int] = None,
+    volume_more_than: typing.Union[float, int] = None,
+    volume_lower_than: typing.Union[float, int] = None,
+    dividend_more_than: typing.Union[float, int] = None,
+    dividend_lower_than: typing.Union[float, int] = None,
     sector: str = None,
     industry: str = None,
     exchange: typing.Union[str, typing.List[str]] = None,
